# -*- coding: utf-8 -*-

import json

from .base import BaseSCenterAPI


class Common(BaseSCenterAPI):
    def signing(self, signing_dict):
        """
        签名
        :param order_dict: 格式参考
        :return:
        """
        return self._post('common/signing/', json=signing_dict).json()

    def odoo_docking(self, data):
        """
        内部商城odoo实例对接平台接口
        :param data:
        :return:
        """
        return self._post('common/docking/', json=data).json()



from .base import BaseModelAPI
from .common import Common
from .delivery import Delivery
from .product import Product
from .tender_sf import TenderSf, TenderSfRound
from .partner import Partner
from .product_shelves_status import ProductShelvesStatus
from .partner_relation import PartnerRelation


# -*- coding: utf-8 -*-

from .base import BaseSCenterAPI


class PartnerRelation(BaseSCenterAPI):
    path = 'ec_partnerrelations/'

    def agree(self, id=None):
        path = self.path + '{}/agree/'.format(id)
        return self._post(path).json()

    def get(self, id=None):
        """
        :param slug:
        :return:
        """
        return self._get('{}{}/'.format(self.path, id)).json()

    def list(self, page=1):
        """
        :param page: 页码
        :return:
        """
        params = {'page': page}
        return self._get(self.path, params=params).json()



# -*- coding: utf-8 -*-

import json

from .base import BaseSCenterAPI


class TenderSf(BaseSCenterAPI):
    path = 'tender_tendersfs/'

    def cancel(self, data):
        path = self.path + 'cancel/'
        return self._post(path, json=data).json()

    def create(self, data):
        path = self.path + 'tendersf/'
        return self._post(path, json=data).json()

    def bidding(self, data):
        path = self.path + 'bidding/'
        return self._post(path, json=data).json()


class TenderSfRound(BaseSCenterAPI):
    path = 'tender_tendersfrounds/'

    def updatetime(self, data):
        path = self.path + 'updatetime/'
        return self._post(path, json=data).json()

    def create(self, data):
        path = self.path + 'newround/'
        return self._post(path, json=data).json()

    def submit(self, data):
        path = self.path + 'submit/'
        return self._post(path, json=data).json()


# -*- coding: utf-8 -*-

import json


class BaseSCenterAPI(object):
    def __init__(self, client=None):
        self._client = client

    def _get(self, url, **kwargs):
        return self._client.get(url, **kwargs)

    def _post(self, url, **kwargs):
        return self._client.post(url, **kwargs)

    def _patch(self, url, **kwargs):
        return self._client.patch(url, **kwargs)


class BaseModelAPI(BaseSCenterAPI):
    """
    CURD基本操作的model配置path即可
    有特殊接口的model，继承本类
    """

    def __init__(self, client, path=None):
        super(BaseModelAPI, self).__init__(client)
        if path:
            self.path = path
            if not path.endswith('/'):
                self.path = path + '/'

    def create(self, data):
        """
        :param data:
        :return:
        """
        return self._post(self.path, json=data).json()

    def get(self, slug=None):
        """
        :param slug:
        :return:
        """
        return self._get("{}{}/".format(self.path, slug)).json()

    def list(self, **kwargs):
        """
        :param slug:
        :return:
        """
        return self._get(self.path, **kwargs).json()

    def update(self, slug, data):
        return self._patch("{}{}/".format(self.path, slug), json=data).json()



from . import api
from .base import BaseSCenterClient


class SCenterClient(BaseSCenterClient):
    # API_BASE_URL = 'http://supplier.cognichain.com/api/v1/'

    @property
    def purchase_order(self):
        return api.BaseModelAPI(self, 'ec_purchaseorders/')

    @property
    def order(self):
        return api.BaseModelAPI(self, 'ec_orders/')

    @property
    def shelves_set(self):
        return api.BaseModelAPI(self, 'ec_shelvessets/')

    @property
    def shelves_set_item(self):
        return api.BaseModelAPI(self, 'ec_shelvesitems/')

    @property
    def aftersale_order(self):
        return api.BaseModelAPI(self, 'ec_aftersaleorders/')

    @property
    def product(self):
        return api.Product(self)

    @property
    def product_shelves_status(self):
        return api.ProductShelvesStatus(self)

    @property
    def common(self):
        return api.Common(self)

    @property
    def delivery(self):
        return api.Delivery(self)

    @property
    def tender_sf(self):
        return api.TenderSf(self)

    @property
    def tender_sf_round(self):
        return api.TenderSfRound(self)

    @property
    def partner(self):
        return api.Partner(self)

    @property
    def partner_relation(self):
        return api.PartnerRelation(self)



# setup.py
from distutils.core import setup

setup(name='scenterpy',
      version='0.4.5',
      author='mayne',
      author_email='dreama9ain@gmail.com',
      url='http://git.cognichain.com:8000/mayne/scenterpy.git',
      packages=['scenterpy', 'scenterpy.client', 'scenterpy.client.api'],
      )
